From: Antoine Coeur <co...@gmx.fr>

Fix various typos in documentation, comments and debug strings.

Cc: Jiaxin Wu <jiaxin...@intel.com>
Cc: Siyuan Fu <siyuan...@intel.com>
Cc: Maciej Rabeda <maciej.rab...@intel.com>
Signed-off-by: Antoine Coeur <co...@gmx.fr>
Reviewed-by: Philippe Mathieu-Daude <phi...@redhat.com>
Reviewed-by: Maciej Rabeda <maciej.rab...@intel.com>
Signed-off-by: Philippe Mathieu-Daude <phi...@redhat.com>
---
 NetworkPkg/TcpDxe/TcpDriver.h     |  8 ++++----
 NetworkPkg/TcpDxe/TcpFunc.h       |  4 ++--
 NetworkPkg/TcpDxe/TcpMain.h       |  4 ++--
 NetworkPkg/TcpDxe/TcpOption.h     |  6 +++---
 NetworkPkg/TcpDxe/TcpProto.h      | 14 +++++++-------
 NetworkPkg/TcpDxe/TcpDispatcher.c |  6 +++---
 NetworkPkg/TcpDxe/TcpDriver.c     | 10 +++++-----
 NetworkPkg/TcpDxe/TcpInput.c      |  8 ++++----
 NetworkPkg/TcpDxe/TcpMain.c       |  4 ++--
 NetworkPkg/TcpDxe/TcpMisc.c       |  2 +-
 NetworkPkg/TcpDxe/TcpOption.c     |  2 +-
 NetworkPkg/TcpDxe/TcpOutput.c     |  4 ++--
 NetworkPkg/TcpDxe/TcpTimer.c      |  2 +-
 13 files changed, 37 insertions(+), 37 deletions(-)

diff --git a/NetworkPkg/TcpDxe/TcpDriver.h b/NetworkPkg/TcpDxe/TcpDriver.h
index 1ac412be6386..b90eed9f60a9 100644
--- a/NetworkPkg/TcpDxe/TcpDriver.h
+++ b/NetworkPkg/TcpDxe/TcpDriver.h
@@ -203,13 +203,13 @@ Tcp6DriverBindingStop (
   );
 
 /**
-  The Callback funtion called after the TCP socket is created.
+  The Callback function called after the TCP socket is created.
 
   @param[in]  This            Pointer to the socket just created.
   @param[in]  Context         The context of the socket.
 
   @retval EFI_SUCCESS         This protocol is installed successfully.
-  @retval other               An error occured.
+  @retval other               An error occurred.
 
 **/
 EFI_STATUS
@@ -248,7 +248,7 @@ TcpDestroySocketCallback (
                                 If it is a pointer to an existing UEFI handle,
                                 then the protocol is added to the existing 
UEFI handle.
 
-  @retval EFI_SUCCES            The protocol was added to ChildHandle.
+  @retval EFI_SUCCESS           The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
   @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child.
@@ -272,7 +272,7 @@ TcpServiceBindingCreateChild (
   @param  This        Pointer to the EFI_SERVICE_BINDING_PROTOCOL instance.
   @param  ChildHandle Handle of the child to destroy.
 
-  @retval EFI_SUCCES            The protocol was removed from ChildHandle.
+  @retval EFI_SUCCESS           The protocol was removed from ChildHandle.
   @retval EFI_UNSUPPORTED       ChildHandle does not support the protocol that 
is being removed.
   @retval EFI_INVALID_PARAMETER The child handle is NULL.
   @retval EFI_ACCESS_DENIED     The protocol could not be removed from the 
ChildHandle
diff --git a/NetworkPkg/TcpDxe/TcpFunc.h b/NetworkPkg/TcpDxe/TcpFunc.h
index 5b8043e8ad52..05cd3c75dc51 100644
--- a/NetworkPkg/TcpDxe/TcpFunc.h
+++ b/NetworkPkg/TcpDxe/TcpFunc.h
@@ -46,7 +46,7 @@ TcpInitTcbLocal (
   Initialize the peer related members.
 
   @param[in, out]  Tcb    Pointer to the TCP_CB of this TCP instance.
-  @param[in]       Seg    Pointer to the segment that contains the peer's 
intial information.
+  @param[in]       Seg    Pointer to the segment that contains the peer's 
initial information.
   @param[in]       Opt    Pointer to the options announced by the peer.
 
 **/
@@ -668,7 +668,7 @@ Tcp6RefreshNeighbor (
 //
 
 /**
-  The procotol handler provided to the socket layer, used to
+  The protocol handler provided to the socket layer, used to
   dispatch the socket level requests by calling the corresponding
   TCP layer functions.
 
diff --git a/NetworkPkg/TcpDxe/TcpMain.h b/NetworkPkg/TcpDxe/TcpMain.h
index 69b35427a17b..35f12a16a87c 100644
--- a/NetworkPkg/TcpDxe/TcpMain.h
+++ b/NetworkPkg/TcpDxe/TcpMain.h
@@ -230,7 +230,7 @@ Tcp4Connect (
   @retval EFI_SUCCESS              The listen token has been queued 
successfully.
   @retval EFI_NOT_STARTED          The EFI_TCP4_PROTOCOL instance hasn't been
                                    configured.
-  @retval EFI_ACCESS_DENIED        The instatnce is not a passive one or it is 
not
+  @retval EFI_ACCESS_DENIED        The instance is not a passive one or it is 
not
                                    in Tcp4StateListen state, or a same listen 
token
                                    has already existed in the listen token 
queue of
                                    this TCP instance.
@@ -565,7 +565,7 @@ Tcp6Connect (
   @retval EFI_INVALID_PARAMETER  One or more of the following are TRUE:
                                  - This is NULL.
                                  - ListenToken is NULL.
-                                 - ListentToken->CompletionToken.Event is NULL.
+                                 - ListenToken->CompletionToken.Event is NULL.
   @retval EFI_OUT_OF_RESOURCES   Could not allocate enough resources to finish 
the operation.
   @retval EFI_DEVICE_ERROR       Any unexpected error not belonging to the 
error
                                  categories given above.
diff --git a/NetworkPkg/TcpDxe/TcpOption.h b/NetworkPkg/TcpDxe/TcpOption.h
index b28f4e63370c..20a476ecebd6 100644
--- a/NetworkPkg/TcpDxe/TcpOption.h
+++ b/NetworkPkg/TcpDxe/TcpOption.h
@@ -40,12 +40,12 @@
 #define TCP_OPTION_MSS_FAST  ((TCP_OPTION_MSS << 24) | (TCP_OPTION_MSS_LEN << 
16))
 
 //
-// Other misc definations
+// Other misc definitions
 //
 #define TCP_OPTION_RCVD_MSS        0x01
 #define TCP_OPTION_RCVD_WS         0x02
 #define TCP_OPTION_RCVD_TS         0x04
-#define TCP_OPTION_MAX_WS          14      ///< Maxium window scale value
+#define TCP_OPTION_MAX_WS          14      ///< Maximum window scale value
 #define TCP_OPTION_MAX_WIN         0xffff  ///< Max window size in TCP header
 
 ///
@@ -111,7 +111,7 @@ TcpBuildOption (
                            successfully pasrsed options.
 
   @retval          0       The options successfully pasrsed.
-  @retval          -1      Ilegal option was found.
+  @retval          -1      Illegal option was found.
 
 **/
 INTN
diff --git a/NetworkPkg/TcpDxe/TcpProto.h b/NetworkPkg/TcpDxe/TcpProto.h
index 403ac98a5c0e..53cfd48026c5 100644
--- a/NetworkPkg/TcpDxe/TcpProto.h
+++ b/NetworkPkg/TcpDxe/TcpProto.h
@@ -86,9 +86,9 @@
 #define TCP_TICK                 200                ///< Every TCP tick is 
200ms.
 #define TCP_TICK_HZ              5                  ///< The frequence of TCP 
tick.
 #define TCP_RTT_SHIFT            3                  ///< SRTT & RTTVAR scaled 
by 8.
-#define TCP_RTO_MIN              TCP_TICK_HZ        ///< The minium value of 
RTO.
-#define TCP_RTO_MAX              (TCP_TICK_HZ * 60) ///< The maxium value of 
RTO.
-#define TCP_FOLD_RTT             4                  ///< Timeout threshod to 
fold RTT.
+#define TCP_RTO_MIN              TCP_TICK_HZ        ///< The minimum value of 
RTO.
+#define TCP_RTO_MAX              (TCP_TICK_HZ * 60) ///< The maximum value of 
RTO.
+#define TCP_FOLD_RTT             4                  ///< Timeout threshold to 
fold RTT.
 
 //
 // Default values for some timers
@@ -103,7 +103,7 @@
 #define TCP_CONNECT_TIME         (75 * TCP_TICK_HZ)
 
 //
-// The header space to be reserved before TCP data to accomodate :
+// The header space to be reserved before TCP data to accommodate:
 // 60byte IP head + 60byte TCP head + link layer head
 //
 #define TCP_MAX_HEAD             192
@@ -236,7 +236,7 @@ struct _TCP_CONTROL_BLOCK {
   LIST_ENTRY        List;     ///< Back and forward link entry
   TCP_CB            *Parent;  ///< The parent TCP_CB structure
 
-  SOCKET            *Sk;      ///< The socket it controled.
+  SOCKET            *Sk;      ///< The socket it controlled.
   TCP_PEER          LocalEnd; ///< Local endpoint.
   TCP_PEER          RemoteEnd;///< Remote endpoint.
 
@@ -320,9 +320,9 @@ struct _TCP_CONTROL_BLOCK {
   //
   UINT32            KeepAliveIdle;   ///< Idle time before sending first probe.
   UINT32            KeepAlivePeriod; ///< Interval for subsequent keep alive 
probe.
-  UINT8             MaxKeepAlive;    ///< Maxium keep alive probe times.
+  UINT8             MaxKeepAlive;    ///< Maximum keep alive probe times.
   UINT8             KeepAliveProbes; ///< The number of keep alive probe.
-  UINT16            MaxRexmit;       ///< The maxium number of retxmit before 
abort.
+  UINT16            MaxRexmit;       ///< The maximum number of retxmit before 
abort.
   UINT32            FinWait2Timeout; ///< The FIN_WAIT_2 timeout.
   UINT32            TimeWaitTimeout; ///< The TIME_WAIT timeout.
   UINT32            ConnectTimeout;  ///< The connect establishment timeout.
diff --git a/NetworkPkg/TcpDxe/TcpDriver.c b/NetworkPkg/TcpDxe/TcpDriver.c
index 1817afa38665..c4dcb5e193ae 100644
--- a/NetworkPkg/TcpDxe/TcpDriver.c
+++ b/NetworkPkg/TcpDxe/TcpDriver.c
@@ -732,13 +732,13 @@ Tcp6DriverBindingStop (
 }
 
 /**
-  The Callback funtion called after the TCP socket was created.
+  The Callback function called after the TCP socket was created.
 
   @param[in]  This            Pointer to the socket just created
   @param[in]  Context         Context of the socket
 
   @retval EFI_SUCCESS         This protocol installed successfully.
-  @retval other               An error occured.
+  @retval other               An error occurred.
 
 **/
 EFI_STATUS
@@ -856,7 +856,7 @@ TcpDestroySocketCallback (
                                 If it is a pointer to an existing UEFI handle,
                                 then the protocol is added to the existing 
UEFI handle.
 
-  @retval EFI_SUCCES            The protocol was added to ChildHandle.
+  @retval EFI_SUCCESS           The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER ChildHandle is NULL.
   @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to 
create
                                 the child.
@@ -888,7 +888,7 @@ TcpServiceBindingCreateChild (
   TcpProto.TcpPcb     = NULL;
 
   //
-  // Create a tcp instance with defualt Tcp default
+  // Create a tcp instance with default Tcp default
   // sock init data and TcpProto
   //
   mTcpDefaultSockData.ProtoData     = &TcpProto;
@@ -930,7 +930,7 @@ TcpServiceBindingCreateChild (
   @param  This        Pointer to the EFI_SERVICE_BINDING_PROTOCOL instance.
   @param  ChildHandle Handle of the child to be destroyed.
 
-  @retval EFI_SUCCES            The protocol was removed from ChildHandle.
+  @retval EFI_SUCCESS           The protocol was removed from ChildHandle.
   @retval EFI_UNSUPPORTED       ChildHandle does not support the protocol that 
is being removed.
   @retval EFI_INVALID_PARAMETER Child handle is NULL.
   @retval EFI_ACCESS_DENIED     The protocol could not be removed from the 
ChildHandle
diff --git a/NetworkPkg/TcpDxe/TcpInput.c b/NetworkPkg/TcpDxe/TcpInput.c
index 42079671ee3a..5e6c8c54cabe 100644
--- a/NetworkPkg/TcpDxe/TcpInput.c
+++ b/NetworkPkg/TcpDxe/TcpInput.c
@@ -246,7 +246,7 @@ TcpComputeRtt (
 
   //
   // Step 2.4: Limit the RTO to at least 1 second
-  // Step 2.5: Limit the RTO to a maxium value that
+  // Step 2.5: Limit the RTO to a maximum value that
   // is at least 60 second
   //
   if (Tcb->Rto < TCP_RTO_MIN) {
@@ -681,7 +681,7 @@ TcpQueueData (
   Adjust the send queue or the retransmit queue.
 
   @param[in]  Tcb      Pointer to the TCP_CB of this TCP instance.
-  @param[in]  Ack      The acknowledge seuqence number of the received segment.
+  @param[in]  Ack      The acknowledge sequence number of the received segment.
 
   @retval          0     An error condition occurred.
   @retval          1     No error occurred.
@@ -1024,7 +1024,7 @@ TcpInput (
         goto StepSix;
       } else {
         //
-        // Received a SYN segment without ACK, simultanous open.
+        // Received a SYN segment without ACK, simultaneous open.
         //
         TcpSetState (Tcb, TCP_SYN_RCVD);
 
@@ -1103,7 +1103,7 @@ TcpInput (
 
       //
       // This TCB comes from either a LISTEN TCB,
-      // or active open TCB with simultanous open.
+      // or active open TCB with simultaneous open.
       // Do NOT signal user CONNECTION refused
       // if it comes from a LISTEN TCB.
       //
diff --git a/NetworkPkg/TcpDxe/TcpMain.c b/NetworkPkg/TcpDxe/TcpMain.c
index fa357cd01a83..75de71eb6ea3 100644
--- a/NetworkPkg/TcpDxe/TcpMain.c
+++ b/NetworkPkg/TcpDxe/TcpMain.c
@@ -282,7 +282,7 @@ Tcp4Connect (
   @retval EFI_SUCCESS              The listen token was queued successfully.
   @retval EFI_NOT_STARTED          The EFI_TCP4_PROTOCOL instance hasn't been
                                    configured.
-  @retval EFI_ACCESS_DENIED        The instatnce is not a passive one or it is 
not
+  @retval EFI_ACCESS_DENIED        The instance is not a passive one or it is 
not
                                    in Tcp4StateListen state or a same listen 
token
                                    has already existed in the listen token 
queue of
                                    this TCP instance.
@@ -795,7 +795,7 @@ Tcp6Connect (
   @retval EFI_INVALID_PARAMETER  One or more of the following are TRUE:
                                  - This is NULL.
                                  - ListenToken is NULL.
-                                 - ListentToken->CompletionToken.Event is NULL.
+                                 - ListenToken->CompletionToken.Event is NULL.
   @retval EFI_OUT_OF_RESOURCES   Could not allocate enough resource to finish 
the operation.
   @retval EFI_DEVICE_ERROR       Any unexpected error not belonging to a 
category listed above.
 
diff --git a/NetworkPkg/TcpDxe/TcpMisc.c b/NetworkPkg/TcpDxe/TcpMisc.c
index 8b0313a02820..73ed33de85ad 100644
--- a/NetworkPkg/TcpDxe/TcpMisc.c
+++ b/NetworkPkg/TcpDxe/TcpMisc.c
@@ -89,7 +89,7 @@ TcpInitTcbLocal (
   Initialize the peer related members.
 
   @param[in, out]  Tcb    Pointer to the TCP_CB of this TCP instance.
-  @param[in]       Seg    Pointer to the segment that contains the peer's 
intial info.
+  @param[in]       Seg    Pointer to the segment that contains the peer's 
initial info.
   @param[in]       Opt    Pointer to the options announced by the peer.
 
 **/
diff --git a/NetworkPkg/TcpDxe/TcpOption.c b/NetworkPkg/TcpDxe/TcpOption.c
index bce814da6c99..c5dbd620e8a0 100644
--- a/NetworkPkg/TcpDxe/TcpOption.c
+++ b/NetworkPkg/TcpDxe/TcpOption.c
@@ -224,7 +224,7 @@ TcpBuildOption (
                            successfully pasrsed options.
 
   @retval          0       The options are successfully pasrsed.
-  @retval          -1      Ilegal option was found.
+  @retval          -1      Illegal option was found.
 
 **/
 INTN
diff --git a/NetworkPkg/TcpDxe/TcpOutput.c b/NetworkPkg/TcpDxe/TcpOutput.c
index 96aada66c8d6..7d0cf0900a66 100644
--- a/NetworkPkg/TcpDxe/TcpOutput.c
+++ b/NetworkPkg/TcpDxe/TcpOutput.c
@@ -477,7 +477,7 @@ TcpGetSegmentSndQue (
 
   //
   // If SYN is set and out of the range, clear the flag.
-  // Becuase the sequence of the first byte is SEG.SEQ+1,
+  // Because the sequence of the first byte is SEG.SEQ+1,
   // adjust Offset by -1. If SYN is in the range, copy
   // one byte less.
   //
@@ -660,7 +660,7 @@ TcpRetransmit (
   UINT32  Len;
 
   //
-  // Compute the maxium length of retransmission. It is
+  // Compute the maximum length of retransmission. It is
   // limited by three factors:
   // 1. Less than SndMss
   // 2. Must in the current send window
diff --git a/NetworkPkg/TcpDxe/TcpTimer.c b/NetworkPkg/TcpDxe/TcpTimer.c
index 2df89094bb91..106d9470dba2 100644
--- a/NetworkPkg/TcpDxe/TcpTimer.c
+++ b/NetworkPkg/TcpDxe/TcpTimer.c
@@ -149,7 +149,7 @@ TcpConnectTimeout (
   if (!TCP_CONNECTED (Tcb->State)) {
     DEBUG (
       (EFI_D_ERROR,
-      "TcpConnectTimeout: connection closed because conenction timer timeout 
for TCB %p\n",
+      "TcpConnectTimeout: connection closed because connection timer timeout 
for TCB %p\n",
       Tcb)
       );
 
diff --git a/NetworkPkg/TcpDxe/TcpDispatcher.c 
b/NetworkPkg/TcpDxe/TcpDispatcher.c
index 9ae08ccc1c56..544817866fa4 100644
--- a/NetworkPkg/TcpDxe/TcpDispatcher.c
+++ b/NetworkPkg/TcpDxe/TcpDispatcher.c
@@ -309,7 +309,7 @@ TcpFlushPcb (
 
     if (Sock->DevicePath != NULL) {
       //
       // Uninstall the device path protocl.
       //
       gBS->UninstallProtocolInterface (
              Sock->SockHandle,
@@ -549,7 +549,7 @@ TcpConfigurePcb (
   }
 
   //
-  // Initalize the operating information in this Tcb
+  // Initialize the operating information in this Tcb
   //
   ASSERT (Tcb->State == TCP_CLOSED &&
     IsListEmpty (&Tcb->SndQue) &&
@@ -751,7 +751,7 @@ TcpConfigurePcb (
 }
 
 /**
-  The procotol handler provided to the socket layer, which is used to
+  The protocol handler provided to the socket layer, which is used to
   dispatch the socket level requests by calling the corresponding
   TCP layer functions.
 
@@ -309,7 +309,7 @@ TcpFlushPcb (
     if (Sock->DevicePath != NULL) {
       //
-      // Uninstall the device path protocl.
+      // Uninstall the device path protocol.
       //
       gBS->UninstallProtocolInterface (
-- 
2.21.1


-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.

View/Reply Online (#53950): https://edk2.groups.io/g/devel/message/53950
Mute This Topic: https://groups.io/mt/71040650/21656
Group Owner: devel+ow...@edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub  [arch...@mail-archive.com]
-=-=-=-=-=-=-=-=-=-=-=-

Reply via email to